@@ -11,7 +11,7 @@
 /*                                                                            */
 /*----------------------------------------------------------------------------*/
 
-static char rcsid[] = "$Id: misc.c 7355 2014-01-19 21:18:21Z storner $";
+static char rcsid[] = "$Id: misc.c 7720 2015-11-04 20:23:13Z jccleaver $";
 
 #include "config.h"
 
@@ -198,6 +198,42 @@ char *skipwhitespace(char *l)
 }
 
 
+char *stripnonwords(char *l)
+{
+	/* Attempt to strip non-word data */
+	static char reduced[255];
+	char *inp;
+	int outidx;
+
+	reduced[0] = '\0';
+	if (!l) return (char *)reduced;
+
+	/* Must be in the set [a-zA-Z0-9_] ... */
+	for (inp=l, outidx=0; (*inp && (outidx < 250)); inp++) {
+		if ( ((*inp >= 'A') && (*inp <= 'Z')) ||
+		     ((*inp >= 'a') && (*inp <= 'z')) ||
+		     ((*inp >= '0') && (*inp <= '9'))  ) {
+			reduced[outidx++] = *inp;
+		}
+			/* Replace anything else with an underscore, */
+			/* compacting successive invalid chars into 1 */
+		else if ((outidx == 0) || (reduced[outidx - 1] != '_')) {
+			reduced[outidx++] = '_';
+		}
+	}
+
+	/* strip a final invalid char */
+	if ((outidx > 0) && (reduced[outidx-1] == '_')) {
+		reduced[outidx-1] = '\0';
+	}
+	else {
+		reduced[outidx] = '\0';
+	}
+
+	return (char *)reduced;
+}
+
+
 int argnmatch(char *arg, char *match)
 {
 	return (strncmp(arg, match, strlen(match)) == 0);
@@ -476,7 +512,7 @@ void do_extensions(FILE *output, char *extenv, char *family)
 	inbuf = newstrbuffer(0);
 
 	while (p) {
-		/* Dont redo the eventlog or acklog things */
+		/* Don't redo the eventlog or acklog things */
 		if ((strcmp(p, "eventlog.sh") != 0) &&
 		    (strcmp(p, "acklog.sh") != 0)) {
 			sprintf(extfn, "%s/ext/%s/%s", xgetenv("XYMONHOME"), family, p);
